/*
 * Copyright (C) 2006 Texas Instruments, Incorporated
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef __GST_GOMX_SRC_H__
#define __GST_GOMX_SRC_H__

#include <gst/gst.h>

#include <gst/base/gstbasesrc.h>

#include <config.h>

G_BEGIN_DECLS

#define GST_GOMX_SRC(obj) (GstGOmxSrc *) (obj)

#if 0
#define GST_TYPE_GOMX_SRC (gst_gomx_src_get_type ())
#define GST_GOMX_SRC(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GST_TYPE_GOMX_SRC, GstGOmxSrc))
#define GST_GOMX_SRC_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_GOMX_SRC, GstGOmxSrcClass))
#define GST_IS_PLUGIN_TEMPLATE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GST_TYPE_GOMX_SRC))
#define GST_IS_PLUGIN_TEMPLATE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GST_TYPE_GOMX_SRC))

GType gst_gomx_src_get_type (void);
#endif

typedef struct _GstGOmxSrc GstGOmxSrc;
typedef struct _GstGOmxSrcClass GstGOmxSrcClass;
typedef struct _GstGOmxSrcElementInfo GstGOmxSrcElementInfo;

#include "gomx.h"

struct _GstGOmxSrc
{
	GstBaseSrc element;

	GstPad *sinkpad;
	GstPad *srcpad;

	gboolean dispose_has_run;

	gboolean silent;

	GOmxCore *gomx;
	GstGOmxSrcElementInfo *info;

	GstCaps *saved_caps;
	guint64 buffer_count;

	gint rate_numerator;
	gint rate_denominator;

	GOmxSem *output_ready;
	GOmxSem *output_filled;
};

struct _GstGOmxSrcClass 
{
	GstBaseSrcClass parent_class;

	GstGOmxSrcElementInfo *info;
};

struct _GstGOmxSrcElementInfo
{
	guint id;
	gchar *name;
	gchar *omx_component;
	gchar *capitalized_name;
	gchar *longname;
	gchar *category;
};

G_END_DECLS

#endif /* __GST_GOMX_SRC_H__ */
